from setuptools import setup, find_packages

setup(
    name='cbeitss',
    version='0.1',
    packages=find_packages(),
    author='Nithingowda A M',
    author_email='nithingowdaam.itss@gmail.com',
    description='simple package',
    long_description='simple package',
    license='MIT',
    classifiers=[
        'Programming Language :: Python :: 2',
        'Programming Language :: Python :: 2.7',
        'License :: OSI Approved :: MIT License',
    ],
)